---
title: Crawl4AI
sidebarTitle: Crawl4AI
---

AG2 now integrates [Crawl4AI](https://docs.crawl4ai.com), an open-source web crawler built for AI agents, language models, and data pipelines. This allows your agents to quickly access and process web data in real time, making automation and data collection more efficient.

import Crawl4AI from "/snippets/reference-tools/crawl4ai.mdx";

<Crawl4AI/>
